
# Flowws Modules for Geometric Algebra Attention Experiments

`flowws-keras-geometry` is a set of
[flowws](https://flowws.readthedocs.io) modules to train machine
learning models using geometric algebra operations in tensorflow and
keras. It contains modules for data sources, architectures for sample
tasks, and analysis and visualization of trained models.

## Installation

Install `flowws-keras-geometry` from source:

```
pip install git+https://github.com/klarh/flowws-keras-geometry.git#egg=flowws-keras-geometry
```

## API Documentation

Build the sphinx documentation from source:

```
git clone https://github.com/klarh/flowws-keras-geometry
cd flowws-keras-geometry/doc
pip install -r requirements.txt
make html
```
